@@ -28,7 +28,7 @@ targets::tar_test("tar_knitr_deps_expr()", {
   writeLines(lines2, report2)
   out <- tar_knitr_deps_expr(c(report1, report2))
   expect_true(is.language(out))
-  out <- deparse_safe(out)
+  out <- targets::tar_deparse_safe(out)
   exp <- "list(data1, data2, data3)"
   expect_equal(out, exp)
 })
